pub struct MultiItemVariationData<'a> {
data: FontData<'a>,
}Fields
data: FontData<'a>Implementations
Sourceimpl<'a> MultiItemVariationData<'a>
impl<'a> MultiItemVariationData<'a>
pub const MIN_SIZE: usize
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
pub fn format(&self) -> u8
pub fn region_index_count(&self) -> u16
pub fn region_indices(&self) -> &'a [BigEndian<u16>]
pub fn raw_delta_sets(&self) -> &'a [u8] ⓘ
pub fn format_byte_range(&self) -> Range<usize> ⓘ
pub fn region_index_count_byte_range(&self) -> Range<usize> ⓘ
pub fn region_indices_byte_range(&self) -> Range<usize> ⓘ
pub fn raw_delta_sets_byte_range(&self) -> Range<usize> ⓘ
Sourceimpl<'a> MultiItemVariationData<'a>
impl<'a> MultiItemVariationData<'a>
Sourcepub fn delta_sets(&self) -> Result<Index2<'a>, ReadError>
pub fn delta_sets(&self) -> Result<Index2<'a>, ReadError>
An Index2 where each item is a PackedDeltas
Sourcepub fn delta_set(&self, i: usize) -> Result<PackedDeltas<'a>, ReadError>
pub fn delta_set(&self, i: usize) -> Result<PackedDeltas<'a>, ReadError>
Read a specific delta set.
Equivalent to calling Self::delta_sets, fetching item i, and parsing as PackedDeltas